@@ -21,3 +21,8 @@ res = r.req("a.root-servers.nex",qtype='ANY')
 res.show()
 res = r.req("proxy.connect.com.au")
 res.show()
+
+# do a TCP reply
+r = DNS.DnsRequest("imsavscan.netvigator.com", qtype="A", server=['8.8.8.8'], protocol='tcp', timeout=300)
+res = r.req()
+res.show()
